@@ -43,33 +43,33 @@ from .paginator import (
     DescribeUsersPaginator,
 )
 from .type_defs import (
-    ActivateUserResponseTypeDef,
-    AddResourcePermissionsResponseTypeDef,
-    CreateCommentResponseTypeDef,
-    CreateFolderResponseTypeDef,
-    CreateNotificationSubscriptionResponseTypeDef,
-    CreateUserResponseTypeDef,
-    DescribeActivitiesResponseTypeDef,
-    DescribeCommentsResponseTypeDef,
-    DescribeDocumentVersionsResponseTypeDef,
-    DescribeFolderContentsResponseTypeDef,
-    DescribeGroupsResponseTypeDef,
-    DescribeNotificationSubscriptionsResponseTypeDef,
-    DescribeResourcePermissionsResponseTypeDef,
-    DescribeRootFoldersResponseTypeDef,
-    DescribeUsersResponseTypeDef,
-    GetCurrentUserResponseTypeDef,
-    GetDocumentPathResponseTypeDef,
-    GetDocumentResponseTypeDef,
-    GetDocumentVersionResponseTypeDef,
-    GetFolderPathResponseTypeDef,
-    GetFolderResponseTypeDef,
-    GetResourcesResponseTypeDef,
-    InitiateDocumentVersionUploadResponseTypeDef,
+    ActivateUserResponseResponseTypeDef,
+    AddResourcePermissionsResponseResponseTypeDef,
+    CreateCommentResponseResponseTypeDef,
+    CreateFolderResponseResponseTypeDef,
+    CreateNotificationSubscriptionResponseResponseTypeDef,
+    CreateUserResponseResponseTypeDef,
+    DescribeActivitiesResponseResponseTypeDef,
+    DescribeCommentsResponseResponseTypeDef,
+    DescribeDocumentVersionsResponseResponseTypeDef,
+    DescribeFolderContentsResponseResponseTypeDef,
+    DescribeGroupsResponseResponseTypeDef,
+    DescribeNotificationSubscriptionsResponseResponseTypeDef,
+    DescribeResourcePermissionsResponseResponseTypeDef,
+    DescribeRootFoldersResponseResponseTypeDef,
+    DescribeUsersResponseResponseTypeDef,
+    GetCurrentUserResponseResponseTypeDef,
+    GetDocumentPathResponseResponseTypeDef,
+    GetDocumentResponseResponseTypeDef,
+    GetDocumentVersionResponseResponseTypeDef,
+    GetFolderPathResponseResponseTypeDef,
+    GetFolderResponseResponseTypeDef,
+    GetResourcesResponseResponseTypeDef,
+    InitiateDocumentVersionUploadResponseResponseTypeDef,
     NotificationOptionsTypeDef,
     SharePrincipalTypeDef,
     StorageRuleTypeTypeDef,
-    UpdateUserResponseTypeDef,
+    UpdateUserResponseResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -120,7 +120,7 @@ class Exceptions:
 
 class WorkDocsClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html)
     """
 
@@ -134,17 +134,17 @@ class WorkDocsClient:
         Aborts the upload of the specified document version that was previously
         initiated by  InitiateDocumentVersionUpload.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.abort_document_version_upload)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.abort_document_version_upload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#abort_document_version_upload)
         """
 
     def activate_user(
         self, *, UserId: str, AuthenticationToken: str = None
-    ) -> ActivateUserResponseTypeDef:
+    ) -> ActivateUserResponseResponseTypeDef:
         """
         Activates the specified user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.activate_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.activate_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#activate_user)
         """
 
@@ -155,11 +155,11 @@ class WorkDocsClient:
         Principals: List["SharePrincipalTypeDef"],
         AuthenticationToken: str = None,
         NotificationOptions: "NotificationOptionsTypeDef" = None
-    ) -> AddResourcePermissionsResponseTypeDef:
+    ) -> AddResourcePermissionsResponseResponseTypeDef:
         """
         Creates a set of permissions for the specified folder or document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.add_resource_permissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.add_resource_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#add_resource_permissions)
         """
 
@@ -167,7 +167,7 @@ class WorkDocsClient:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#can_paginate)
         """
 
@@ -182,11 +182,11 @@ class WorkDocsClient:
         ThreadId: str = None,
         Visibility: CommentVisibilityTypeType = None,
         NotifyCollaborators: bool = None
-    ) -> CreateCommentResponseTypeDef:
+    ) -> CreateCommentResponseResponseTypeDef:
         """
         Adds a new comment to the specified document version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.create_comment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.create_comment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_comment)
         """
 
@@ -202,17 +202,17 @@ class WorkDocsClient:
         Adds one or more custom properties to the specified resource (a folder,
         document, or version).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.create_custom_metadata)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.create_custom_metadata)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_custom_metadata)
         """
 
     def create_folder(
         self, *, ParentFolderId: str, AuthenticationToken: str = None, Name: str = None
-    ) -> CreateFolderResponseTypeDef:
+    ) -> CreateFolderResponseResponseTypeDef:
         """
         Creates a folder with the specified name and parent folder.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.create_folder)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.create_folder)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_folder)
         """
 
@@ -226,7 +226,7 @@ class WorkDocsClient:
         **Request Syntax** response = client.create_labels( ResourceId='string',
         Labels=[ ...
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.create_labels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.create_labels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_labels)
         """
 
@@ -237,11 +237,11 @@ class WorkDocsClient:
         Endpoint: str,
         Protocol: Literal["HTTPS"],
         SubscriptionType: Literal["ALL"]
-    ) -> CreateNotificationSubscriptionResponseTypeDef:
+    ) -> CreateNotificationSubscriptionResponseResponseTypeDef:
         """
         Configure Amazon WorkDocs to use Amazon SNS notifications.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.create_notification_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.create_notification_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_notification_subscription)
         """
 
@@ -257,11 +257,11 @@ class WorkDocsClient:
         TimeZoneId: str = None,
         StorageRule: "StorageRuleTypeTypeDef" = None,
         AuthenticationToken: str = None
-    ) -> CreateUserResponseTypeDef:
+    ) -> CreateUserResponseResponseTypeDef:
         """
         Creates a user in a Simple AD or Microsoft AD directory.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.create_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.create_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#create_user)
         """
 
@@ -270,7 +270,7 @@ class WorkDocsClient:
         Deactivates the specified user, which revokes the user's access to Amazon
         WorkDocs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.deactivate_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.deactivate_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#deactivate_user)
         """
 
@@ -280,7 +280,7 @@ class WorkDocsClient:
         """
         Deletes the specified comment from the document version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.delete_comment)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.delete_comment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_comment)
         """
 
@@ -296,7 +296,7 @@ class WorkDocsClient:
         """
         Deletes custom metadata from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.delete_custom_metadata)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.delete_custom_metadata)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_custom_metadata)
         """
 
@@ -304,7 +304,7 @@ class WorkDocsClient:
         """
         Permanently deletes the specified document and its associated metadata.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.delete_document)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.delete_document)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_document)
         """
 
@@ -312,7 +312,7 @@ class WorkDocsClient:
         """
         Permanently deletes the specified folder and its contents.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.delete_folder)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.delete_folder)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_folder)
         """
 
@@ -320,7 +320,7 @@ class WorkDocsClient:
         """
         Deletes the contents of the specified folder.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.delete_folder_contents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.delete_folder_contents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_folder_contents)
         """
 
@@ -335,7 +335,7 @@ class WorkDocsClient:
         """
         Deletes the specified list of labels from a resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.delete_labels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.delete_labels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_labels)
         """
 
@@ -343,7 +343,7 @@ class WorkDocsClient:
         """
         Deletes the specified subscription from the specified organization.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.delete_notification_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.delete_notification_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_notification_subscription)
         """
 
@@ -351,7 +351,7 @@ class WorkDocsClient:
         """
         Deletes the specified user from a Simple AD or Microsoft AD directory.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.delete_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.delete_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#delete_user)
         """
 
@@ -368,11 +368,11 @@ class WorkDocsClient:
         IncludeIndirectActivities: bool = None,
         Limit: int = None,
         Marker: str = None
-    ) -> DescribeActivitiesResponseTypeDef:
+    ) -> DescribeActivitiesResponseResponseTypeDef:
         """
         Describes the user activities in a specified time period.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.describe_activities)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.describe_activities)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_activities)
         """
 
@@ -384,11 +384,11 @@ class WorkDocsClient:
         AuthenticationToken: str = None,
         Limit: int = None,
         Marker: str = None
-    ) -> DescribeCommentsResponseTypeDef:
+    ) -> DescribeCommentsResponseResponseTypeDef:
         """
         List all the comments for the specified document version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.describe_comments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.describe_comments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_comments)
         """
 
@@ -401,11 +401,11 @@ class WorkDocsClient:
         Limit: int = None,
         Include: str = None,
         Fields: str = None
-    ) -> DescribeDocumentVersionsResponseTypeDef:
+    ) -> DescribeDocumentVersionsResponseResponseTypeDef:
         """
         Retrieves the document versions for the specified document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.describe_document_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.describe_document_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_document_versions)
         """
 
@@ -420,12 +420,12 @@ class WorkDocsClient:
         Marker: str = None,
         Type: FolderContentTypeType = None,
         Include: str = None
-    ) -> DescribeFolderContentsResponseTypeDef:
+    ) -> DescribeFolderContentsResponseResponseTypeDef:
         """
         Describes the contents of the specified folder, including its documents and
         subfolders.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.describe_folder_contents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.describe_folder_contents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_folder_contents)
         """
 
@@ -437,21 +437,21 @@ class WorkDocsClient:
         OrganizationId: str = None,
         Marker: str = None,
         Limit: int = None
-    ) -> DescribeGroupsResponseTypeDef:
+    ) -> DescribeGroupsResponseResponseTypeDef:
         """
         Describes the groups specified by the query.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.describe_groups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.describe_groups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_groups)
         """
 
     def describe_notification_subscriptions(
         self, *, OrganizationId: str, Marker: str = None, Limit: int = None
-    ) -> DescribeNotificationSubscriptionsResponseTypeDef:
+    ) -> DescribeNotificationSubscriptionsResponseResponseTypeDef:
         """
         Lists the specified notification subscriptions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.describe_notification_subscriptions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.describe_notification_subscriptions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_notification_subscriptions)
         """
 
@@ -463,22 +463,22 @@ class WorkDocsClient:
         PrincipalId: str = None,
         Limit: int = None,
         Marker: str = None
-    ) -> DescribeResourcePermissionsResponseTypeDef:
+    ) -> DescribeResourcePermissionsResponseResponseTypeDef:
         """
         Describes the permissions of a specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.describe_resource_permissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.describe_resource_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_resource_permissions)
         """
 
     def describe_root_folders(
         self, *, AuthenticationToken: str, Limit: int = None, Marker: str = None
-    ) -> DescribeRootFoldersResponseTypeDef:
+    ) -> DescribeRootFoldersResponseResponseTypeDef:
         """
         Describes the current user's special folders; the `RootFolder` and the
         `RecycleBin`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.describe_root_folders)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.describe_root_folders)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_root_folders)
         """
 
@@ -495,11 +495,11 @@ class WorkDocsClient:
         Marker: str = None,
         Limit: int = None,
         Fields: str = None
-    ) -> DescribeUsersResponseTypeDef:
+    ) -> DescribeUsersResponseResponseTypeDef:
         """
         Describes the specified users.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.describe_users)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.describe_users)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#describe_users)
         """
 
@@ -513,16 +513,18 @@ class WorkDocsClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#generate_presigned_url)
         """
 
-    def get_current_user(self, *, AuthenticationToken: str) -> GetCurrentUserResponseTypeDef:
+    def get_current_user(
+        self, *, AuthenticationToken: str
+    ) -> GetCurrentUserResponseResponseTypeDef:
         """
         Retrieves details of the current user for whom the authentication token was
         generated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.get_current_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.get_current_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_current_user)
         """
 
@@ -532,11 +534,11 @@ class WorkDocsClient:
         DocumentId: str,
         AuthenticationToken: str = None,
         IncludeCustomMetadata: bool = None
-    ) -> GetDocumentResponseTypeDef:
+    ) -> GetDocumentResponseResponseTypeDef:
         """
         Retrieves details of a document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.get_document)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.get_document)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_document)
         """
 
@@ -548,12 +550,12 @@ class WorkDocsClient:
         Limit: int = None,
         Fields: str = None,
         Marker: str = None
-    ) -> GetDocumentPathResponseTypeDef:
+    ) -> GetDocumentPathResponseResponseTypeDef:
         """
         Retrieves the path information (the hierarchy from the root folder) for the
         requested document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.get_document_path)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.get_document_path)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_document_path)
         """
 
@@ -565,21 +567,21 @@ class WorkDocsClient:
         AuthenticationToken: str = None,
         Fields: str = None,
         IncludeCustomMetadata: bool = None
-    ) -> GetDocumentVersionResponseTypeDef:
+    ) -> GetDocumentVersionResponseResponseTypeDef:
         """
         Retrieves version metadata for the specified document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.get_document_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.get_document_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_document_version)
         """
 
     def get_folder(
         self, *, FolderId: str, AuthenticationToken: str = None, IncludeCustomMetadata: bool = None
-    ) -> GetFolderResponseTypeDef:
+    ) -> GetFolderResponseResponseTypeDef:
         """
         Retrieves the metadata of the specified folder.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.get_folder)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.get_folder)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_folder)
         """
 
@@ -591,12 +593,12 @@ class WorkDocsClient:
         Limit: int = None,
         Fields: str = None,
         Marker: str = None
-    ) -> GetFolderPathResponseTypeDef:
+    ) -> GetFolderPathResponseResponseTypeDef:
         """
         Retrieves the path information (the hierarchy from the root folder) for the
         specified folder.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.get_folder_path)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.get_folder_path)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_folder_path)
         """
 
@@ -608,11 +610,11 @@ class WorkDocsClient:
         CollectionType: Literal["SHARED_WITH_ME"] = None,
         Limit: int = None,
         Marker: str = None
-    ) -> GetResourcesResponseTypeDef:
+    ) -> GetResourcesResponseResponseTypeDef:
         """
         Retrieves a collection of resources, including folders and documents.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.get_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.get_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#get_resources)
         """
 
@@ -627,11 +629,11 @@ class WorkDocsClient:
         ContentModifiedTimestamp: Union[datetime, str] = None,
         ContentType: str = None,
         DocumentSizeInBytes: int = None
-    ) -> InitiateDocumentVersionUploadResponseTypeDef:
+    ) -> InitiateDocumentVersionUploadResponseResponseTypeDef:
         """
         Creates a new document object and version object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.initiate_document_version_upload)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.initiate_document_version_upload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#initiate_document_version_upload)
         """
 
@@ -641,7 +643,7 @@ class WorkDocsClient:
         """
         Removes all the permissions from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.remove_all_resource_permissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.remove_all_resource_permissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#remove_all_resource_permissions)
         """
 
@@ -656,7 +658,7 @@ class WorkDocsClient:
         """
         Removes the permission for the specified principal from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.remove_resource_permission)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.remove_resource_permission)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#remove_resource_permission)
         """
 
@@ -672,7 +674,7 @@ class WorkDocsClient:
         """
         Updates the specified attributes of a document.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.update_document)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.update_document)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#update_document)
         """
 
@@ -687,7 +689,7 @@ class WorkDocsClient:
         """
         Changes the status of the document version to ACTIVE.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.update_document_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.update_document_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#update_document_version)
         """
 
@@ -703,7 +705,7 @@ class WorkDocsClient:
         """
         Updates the specified attributes of the specified folder.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.update_folder)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.update_folder)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#update_folder)
         """
 
@@ -719,12 +721,12 @@ class WorkDocsClient:
         TimeZoneId: str = None,
         Locale: LocaleTypeType = None,
         GrantPoweruserPrivileges: BooleanEnumTypeType = None
-    ) -> UpdateUserResponseTypeDef:
+    ) -> UpdateUserResponseResponseTypeDef:
         """
         Updates the specified attributes of the specified user, and grants or revokes
         administrative privileges to the Amazon WorkDocs site.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Client.update_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Client.update_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client.html#update_user)
         """
 
@@ -733,7 +735,7 @@ class WorkDocsClient:
         self, operation_name: Literal["describe_activities"]
     ) -> DescribeActivitiesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Paginator.DescribeActivities)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Paginator.DescribeActivities)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeactivitiespaginator)
         """
 
@@ -742,7 +744,7 @@ class WorkDocsClient:
         self, operation_name: Literal["describe_comments"]
     ) -> DescribeCommentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Paginator.DescribeComments)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Paginator.DescribeComments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describecommentspaginator)
         """
 
@@ -751,7 +753,7 @@ class WorkDocsClient:
         self, operation_name: Literal["describe_document_versions"]
     ) -> DescribeDocumentVersionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Paginator.DescribeDocumentVersions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Paginator.DescribeDocumentVersions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describedocumentversionspaginator)
         """
 
@@ -760,14 +762,14 @@ class WorkDocsClient:
         self, operation_name: Literal["describe_folder_contents"]
     ) -> DescribeFolderContentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Paginator.DescribeFolderContents)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Paginator.DescribeFolderContents)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describefoldercontentspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_groups"]) -> DescribeGroupsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Paginator.DescribeGroups)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Paginator.DescribeGroups)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describegroupspaginator)
         """
 
@@ -776,7 +778,7 @@ class WorkDocsClient:
         self, operation_name: Literal["describe_notification_subscriptions"]
     ) -> DescribeNotificationSubscriptionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Paginator.DescribeNotificationSubscriptions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Paginator.DescribeNotificationSubscriptions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describenotificationsubscriptionspaginator)
         """
 
@@ -785,7 +787,7 @@ class WorkDocsClient:
         self, operation_name: Literal["describe_resource_permissions"]
     ) -> DescribeResourcePermissionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Paginator.DescribeResourcePermissions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Paginator.DescribeResourcePermissions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeresourcepermissionspaginator)
         """
 
@@ -794,13 +796,13 @@ class WorkDocsClient:
         self, operation_name: Literal["describe_root_folders"]
     ) -> DescribeRootFoldersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Paginator.DescribeRootFolders)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Paginator.DescribeRootFolders)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describerootfolderspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_users"]) -> DescribeUsersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/workdocs.html#WorkDocs.Paginator.DescribeUsers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/workdocs.html#WorkDocs.Paginator.DescribeUsers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeuserspaginator)
         """
